==> dde-shell_1.99.36.tar.xz: BUILD/panels/notification/center/translations/org.deepin.ds.notificationcenter_hu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu">
<context>
    <name>GroupNotify</name>
    <message>
        <source>Clear All</source>
        <translation>Összes törlése</translation>
    </message>
</context>
<context>
    <name>NotifyHeader</name>
    <message>
        <source>Notification Center</source>
        <translation>Értesítési Központ</translation>
    </message>
    <message>
        <source>Clear All</source>
        <translation>Összes törlése</translation>
    </message>
</context>
<context>
    <name>NotifySetting</name>
    <message>
        <source>Unpin</source>
        <translation>Feloldás</translation>
    </message>
    <message>
        <source>Pin</source>
        <translation>Rögzítés</translation>
    </message>
    <message>
        <source>Notification Setting</source>
        <translation>Értesítési Beállítások</translation>
    </message>
</context>
<context>
    <name>notifycenter::AppNotifyItem</name>
    <message>
        <source>Just now</source>
        <translation>Csak most</translation>
    </message>
    <message>
        <source>%1 minutes ago</source>
        <translation>%1 perccel ezelőtt</translation>
    </message>
    <message>
        <source>1 hour ago</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 hours ago</source>
        <translation>%1 órával ezelőtt</translation>
    </message>
    <message>
        <source>Yesterday </source>
        <translation>Tegnap</translation>
    </message>
</context>
</TS>

==> dde-shell_2.0.3.tar.xz: BUILD/panels/notification/center/translations/org.deepin.ds.notificationcenter_hu.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="hu">
<context>
    <name>GroupNotify</name>
    <message>
        <source>Clear All</source>
        <translation>Összes törlése</translation>
    </message>
</context>
<context>
    <name>NotifyHeader</name>
    <message>
        <source>Notification Center</source>
        <translation>Értesítési Központ</translation>
    </message>
    <message>
        <source>Clear All</source>
        <translation>Összes törlése</translation>
    </message>
</context>
<context>
    <name>NotifySetting</name>
    <message>
        <source>Unpin</source>
        <translation>Feloldás</translation>
    </message>
    <message>
        <source>Pin</source>
        <translation>Rögzítés</translation>
    </message>
    <message>
        <source>Notification Setting</source>
        <translation>Értesítési Beállítások</translation>
    </message>
</context>
<context>
    <name>notifycenter::AppNotifyItem</name>
    <message>
        <source>Just now</source>
        <translation>Csak most</translation>
    </message>
    <message>
        <source>%1 minutes ago</source>
        <translation>%1 perccel ezelőtt</translation>
    </message>
    <message>
        <source>1 hour ago</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>%1 hours ago</source>
        <translation>%1 órával ezelőtt</translation>
    </message>
    <message>
        <source>Yesterday </source>
        <translation>Tegnap</translation>
    </message>
</context>
</TS>
